@@ -8,14 +8,16 @@ use Keyword::Declare;
 use Carp;
 
 sub import {
-    keyword try (Block $block) {{{
-        { my $CATCH; eval { <{$block->reline}> 1 } // do{ my $error = $@; $CATCH->($error) }; }
-    }}}
+    keytype CatchParam is / \( (?&PerlOWS) (?&PerlVariableScalar) (?&PerlOWS) \) /x;
 
-    keyword CATCH (List $param = '($'.('_'x50).'v)', Block $block) {{{
+    keyword CATCH (CatchParam $param = '($_______________________v)', Block $block) :desc(CATCH phaser) {{{
         BEGIN { eval'$CATCH=$CATCH;1' // die q{Can't specify CATCH block outside a try};              }
         BEGIN { die q{Can't specify two CATCH blocks inside a single try} if defined $CATCH;          }
-        BEGIN { $CATCH = sub { use experimentals; my <{$param}> = @_; given (<{$param}>) <{$block->reline}> } }
+        BEGIN { $CATCH = sub { use experimentals; my <{$param}> = @_; given (<{$param}>) <{$block}> } }
+    }}}
+
+    keyword try (Block $block) {{{
+        { my $CATCH; eval { <{$block}> 1 } // do{ my $error = $@; eval{ $CATCH->($error) } }; }
     }}}
 }
 
